pub struct QueryPredicate {
pub operator: Box<str>,
pub args: Box<[QueryPredicateArg]>,
}Expand description
A key-value pair associated with a particular pattern in a Query.
Fields
operator: Box<str>args: Box<[QueryPredicateArg]>Trait Implementations
Sourceimpl Clone for QueryPredicate
impl Clone for QueryPredicate
Sourcefn clone(&self) -> QueryPredicate
fn clone(&self) -> QueryPredicate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QueryPredicate
impl Debug for QueryPredicate
impl Eq for QueryPredicate
Sourceimpl PartialEq for QueryPredicate
impl PartialEq for QueryPredicate
Sourcefn eq(&self, other: &QueryPredicate) -> bool
fn eq(&self, other: &QueryPredicate) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for QueryPredicate